@@ -220,7 +220,8 @@ class Segment:
         bool
             whether the segment is valid
         """
-        return hu.is_segment_feasible(self.to_array(), v_des, a_des)
+        success,v_max,a_max=hu.is_segment_feasible(self.to_array(), v_des, a_des)
+        return success
 
 
 class Spline:
@@ -408,7 +409,7 @@ class Spline:
         """
         # only check if valid if there are enough waypoints
         if len(self.waypoints) < 2:
-            return True, "must have atleast two waypoints"
+            return True, "must have at least two waypoints"
 
         # verify that spline starts at time zero
         if not np.isclose(self.waypoints[0].time, 0.0, atol=WAYPOINT_ISCLOSE_ATOL):
@@ -424,11 +425,11 @@ class Spline:
             if waypoint.time < t:
                 return False, "time must increase for each subsequent waypoint"
             t = waypoint.time
-
         # verify spline adheres to joint dynamics limits
         for i in range(self.get_num_segments()):
-            if not hu.is_segment_feasible(self.get_segment(i).to_array(), v_des, a_des):
-                return False, "segment {0} exceeds dynamic bounds".format(i)
+            success, v_max, a_max=hu.is_segment_feasible(self.get_segment(i).to_array(), v_des, a_des)
+            if not success:
+                return False, "segment %d exceeds dynamic bounds of (%f vel | %f acc ) with max of (%f vel | %f acc )"%(i,v_des,a_des,v_max,a_max)
 
         return True, ""
 
@@ -673,8 +674,9 @@ class DiffDriveTrajectory(Spline):
             whether the segment is valid, and error message if not
         """
         # only check if valid if there are enough waypoints
+
         if len(self.waypoints) < 2:
-            return True, "must have atleast two waypoints"
+            return True, "must have at least two waypoints"
 
         # verify that spline starts at time zero
         if not np.isclose(self.waypoints[0].time, 0.0, atol=WAYPOINT_ISCLOSE_ATOL):
@@ -702,9 +704,21 @@ class DiffDriveTrajectory(Spline):
         # verify left and right trajectories adheres to joint dynamics limits
         for i in range(self.get_num_segments()):
             ls, rs = self.get_wheel_segments(i, translate_to_motor_rad, rotate_to_motor_rad)
-            if not hu.is_segment_feasible(ls.to_array(), v_des, a_des):
-                return False, "left wheel segment {0} exceeds dynamic bounds".format(i)
-            if not hu.is_segment_feasible(rs.to_array(), v_des, a_des):
-                return False, "right wheel segment {0} exceeds dynamic bounds".format(i)
+            success, v_max, a_max =hu.is_segment_feasible(ls.to_array(), v_des, a_des)
+            if not success:
+                return False, "left wheel segment %d exceeds dynamic bounds of (%f vel | %f acc ) with max of (%f vel | %f acc )"%(i,v_des,a_des,v_max,a_max)
+            success, v_max, a_max =hu.is_segment_feasible(rs.to_array(), v_des, a_des)
+            if not success:
+                return False, "right wheel segment %d exceeds dynamic bounds of (%f vel | %f acc ) with max of (%f vel | %f acc )"%(i,v_des,a_des,v_max,a_max)
+
+        # verify that either x or theta is zero (translate or rotate only at a time)
+        for i in range(1,len(self.waypoints)):
+            dx=self.waypoints[i].pose[0]-self.waypoints[i-1].pose[0]
+            dy = self.waypoints[i].pose[1] - self.waypoints[i-1].pose[1]
+            dtheta = self.waypoints[i].pose[2] - self.waypoints[i-1].pose[2]
+            if not np.isclose(dy, 0.0, atol=WAYPOINT_ISCLOSE_ATOL):
+                return False, 'DiffDriveTrajectory does not support motion in Y direction: \n%s'%str(self.waypoints[i])
+            if (not np.isclose(dx, 0.0, atol=WAYPOINT_ISCLOSE_ATOL)) and (not np.isclose(dtheta, 0.0, atol=WAYPOINT_ISCLOSE_ATOL)):
+                return False, 'DiffDriveTrajectory waypoint cannot both translate and rotate: \n%s'%str(self.waypoints[i])
 
         return True, ""
